@@ -27,9 +27,12 @@
 #include "uml.h"
 
 // kde includes
+#if QT_VERSION >= 0x050000
+#else
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#endif
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // qt includes
 #include <QFileInfo>
@@ -43,7 +46,7 @@ CodeImportingWizard::CodeImportingWizard()
   : QWizard((QWidget*)UMLApp::app())
 {
     setWizardStyle(QWizard::ModernStyle);
-    setPixmap(QWizard::LogoPixmap, Icon_Utils::UserIcon(Icon_Utils::it_Code_Gen_Wizard));
+    setPixmap(QWizard::LogoPixmap, Icon_Utils::DesktopIcon(Icon_Utils::it_Code_Gen_Wizard));
     setWindowTitle(i18n("Code Importing Wizard"));
     setOption(QWizard::NoBackButtonOnStartPage, true);
 
