@@ -91,7 +91,7 @@ ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLClassifier *c)
  * Constructs a ClassifierWidget.
  *
  * @param scene   The parent of this ClassifierWidget.
- * @param c       The UMLClassifier to represent.
+ * @param o       The UMLPackage to represent.
  */
 ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLPackage *o)
   : UMLWidget(scene, WidgetBase::wt_Package, o),
@@ -703,7 +703,7 @@ AssociationWidget *ClassifierWidget::classAssociationWidget() const
 /**
  * Overrides standard method.
  * Auxiliary to reimplementations in the derived classes.
- * @NOTE keep fetching attributes in sync with calculateSize()
+ * @note keep fetching attributes in sync with calculateSize()
  */
 void ClassifierWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
@@ -884,7 +884,7 @@ QPainterPath ClassifierWidget::shape() const
 {
     QPainterPath path;
     if (classifier() && classifier()->isInterface() && visualProperty(DrawAsCircle)) {
-        path.addEllipse(rect());
+        path.addEllipse(QRectF(QPointF(), calculateAsCircleSize()));
         return path;
     }
     QSizeF mainSize = rect().size();
@@ -905,6 +905,8 @@ QPainterPath ClassifierWidget::shape() const
  */
 void ClassifierWidget::drawAsCircle(QPainter *painter, const QStyleOptionGraphicsItem *option)
 {
+    Q_UNUSED(option);
+
     const int w = width();
 
     if (associationWidgetList().size() > 1) {
@@ -966,8 +968,6 @@ void ClassifierWidget::drawAsCircle(QPainter *painter, const QStyleOptionGraphic
     }
     else
         painter->drawEllipse(w/2 - CIRCLE_SIZE/2, 0, CIRCLE_SIZE, CIRCLE_SIZE);
-
-    UMLWidget::paint(painter, option);
 }
 
 /**
@@ -1157,6 +1157,7 @@ void ClassifierWidget::setDrawAsCircle(bool drawAsCircle)
             m_pInterfaceName->hide();
         m_resizable = true;
     }
+    setChangesShape(drawAsCircle);
     updateGeometry();
     update();
 }
@@ -1234,22 +1235,6 @@ void ClassifierWidget::changeToPackage()
     updateGeometry();
     update();
 }
-/**
- * @brief ClassifierWidget::changeToInstance
- * Change this classifier from a class or interface to a Instance
- * This widget is also updated
- */
-void ClassifierWidget::changeToInstance()
-{
-    setBaseType(WidgetBase::wt_Instance);
-    m_umlObject->setBaseType(UMLObject::ot_Instance);
-    setVisualProperty(ShowAttributes, true);
-    setVisualProperty(ShowStereotype, false);
-    setVisualProperty(ShowOperations,false);
-
-    updateGeometry();
-    update();
-}
 
 /**
  * Extends base method to adjust also the association of a class
@@ -1297,12 +1282,14 @@ bool ClassifierWidget::loadFromXMI1(QDomElement & qElement)
         QString showpackage = qElement.attribute(QLatin1String("showpackage"), QLatin1String("0"));
         QString showscope = qElement.attribute(QLatin1String("showscope"), QLatin1String("0"));
         QString drawascircle = qElement.attribute(QLatin1String("drawascircle"), QLatin1String("0"));
+        QString showstereotype = qElement.attribute(QLatin1String("showstereotype"), QLatin1String("1"));
         setVisualPropertyCmd(ShowAttributes, (bool)showatts.toInt());
         setVisualPropertyCmd(ShowOperations, (bool)showops.toInt());
         setVisualPropertyCmd(ShowPublicOnly, (bool)showpubliconly.toInt());
         setVisualPropertyCmd(ShowPackage,    (bool)showpackage.toInt());
         setVisualPropertyCmd(ShowVisibility, (bool)showscope.toInt());
         setVisualPropertyCmd(DrawAsCircle,   (bool)drawascircle.toInt());
+        setVisualPropertyCmd(ShowStereotype, (bool)showstereotype.toInt());
         m_attributeSignature = Uml::SignatureType::fromInt(showattsigs.toInt());
         m_operationSignature = Uml::SignatureType::fromInt(showopsigs.toInt());
     }
@@ -1371,6 +1358,7 @@ void ClassifierWidget::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
         conceptElement.setAttribute(QLatin1String("showscope"),      visualProperty(ShowVisibility));
         conceptElement.setAttribute(QLatin1String("showattributes"), visualProperty(ShowAttributes));
         conceptElement.setAttribute(QLatin1String("showattsigs"),    m_attributeSignature);
+        conceptElement.setAttribute(QLatin1String("showstereotype"), visualProperty(ShowStereotype));
     }
 #ifdef ENABLE_WIDGET_SHOW_DOC
     conceptElement.setAttribute(QLatin1String("showdocumentation"),visualProperty(ShowDocumentation));
@@ -1485,10 +1473,6 @@ void ClassifierWidget::slotMenuSelection(QAction* action)
         changeToPackage();
         break;
 
-    case ListPopupMenu::mt_ChangeToInstance:
-        changeToInstance();
-        break;
-
     default:
         UMLWidget::slotMenuSelection(action);
         break;
@@ -1511,3 +1495,27 @@ void ClassifierWidget::slotShowOperations(bool state)
     setVisualProperty(ShowOperations, state);
 }
 
+/**
+ * Show a properties dialog for a ClassifierWidget
+ */
+bool ClassifierWidget::showPropertiesDialog()
+{
+    if (UMLWidget::showPropertiesDialog()) {
+        if (isInterfaceWidget() && visualProperty(DrawAsCircle))
+            m_pInterfaceName->setText(name());
+        return true;
+    }
+    return false;
+}
+
+/**
+ * Overriding the method from WidgetBase because we need to do
+ * something extra in case this ClassifierWidget represents
+ * an interface widget used in component diagrams.
+ */
+void ClassifierWidget::setUMLObject(UMLObject *obj)
+{
+    WidgetBase::setUMLObject(obj);
+    if (isInterfaceWidget() && visualProperty(DrawAsCircle))
+        m_pInterfaceName->setText(obj->name());
+}
